@@ -32,7 +32,7 @@ KCupsPasswordDialog::KCupsPasswordDialog(QObject *parent) :
     QObject(parent),
     m_accepted(false),
     m_mainwindow(0),
-    // default text, can be overriden using setPromptText()
+    // default text, can be overridden using setPromptText()
     m_promptText(i18n("Enter an username and a password to complete the task"))
 {
 }
@@ -60,7 +60,8 @@ void KCupsPasswordDialog::exec(const QString &username, bool wrongPassword)
 
     dialog->show();
     if (m_mainwindow) {
-        KWindowSystem::setMainWindow(dialog, m_mainwindow);
+        dialog->setAttribute(Qt::WA_NativeWindow, true);
+        KWindowSystem::setMainWindow(dialog->windowHandle(), m_mainwindow);
     }
     KWindowSystem::forceActiveWindow(dialog->winId());
 
